# argufy

%NPM: argufy%

```sh
yarn add -E argufy
```

`argufy` will parse command line arguments to Node.js CLI programs.

%TOC%

## API

The package assumes that the arguments begin from the 3rd position, i.e.,

```sh
node example.js --title "Hello World"
```

```### argufy => object
[
  ["config", "<string, ConfigItem>"],
  ["argv?", "string[]"]
]
```

The flags from the arguments will be extracted according to the configuration object and the arguments array. If arguments array is not passed, `process.argv` is used to find arguments.

%EXAMPLE: example/example.js, ../src => argufy, javascript%

```sh
node example.js --title Hello_World -w 10 -l -app Argufy
# or
node example.js Hello_World -w 10 -l -app Argufy
# no support "for arguments with space"
```

%FORK-json example example/example.js --title Hello_World -w 10 -l -app Argufy%

The special [`_argv property`](t) will be assigned to contain all unmatched arguments. For example, it can be used to pass any additional parameters through to other program.

### `ConfigItem` Type

The configuration for each flag can either be a shorthand string, or an object. If it is an object, it can include the following parameters:

```table
[
  ["Property", "Type", "Description", "Example"],
  ["`short`", "string", "A short version of the argument.", "`program -t title`"],
  ["`boolean`", "boolean", "Parse argument as a number.", "`program -n 10`"],
  ["`command`", "boolean", "Can this argument be a command, i.e., be the first argument without having to follow a flag. Sets the argument to be a string.", "`program command`"],
  ["`multiple`", "boolean", "If `command` is true, should multiple words be parsed as an array of commands. Sets the argument to be an array of strings.", "`program command1 command2`"]
]
```

---

(c) [artdecocode][1] 2018

[1]: https://artdeco.bz
