import { equal, deepEqual } from 'zoroaster/assert'
import Context from '../context'
import argufy from '../../src'

/** @type {Object.<string, (c: Context)>} */
const T = {
  context: Context,
  'is a function'() {
    equal(typeof argufy, 'function')
  },
  'extracts some arguments'({ config, TITLE, WAIT }) {
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', '--title', TITLE, '-w', `${WAIT}`]
    const res = argufy(config, args)
    deepEqual(res, {
      _argv: [],
      title: TITLE,
      wait: WAIT,
    })
  },
  'extracts a command'({ config, TITLE, WAIT }) {
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', TITLE, '-w', `${WAIT}`]
    const res = argufy(config, args)
    deepEqual(res, {
      _argv: [],
      title: TITLE,
      wait: WAIT,
    })
  },
  'extracts commands'({ TITLE, WAIT }) {
    const TITLE2 = `${TITLE}2`
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', TITLE, TITLE2, '-w', WAIT]
    const res = argufy({
      title: {
        command: true,
        multiple: true,
      },
      wait: 'w',
    }, args)
    deepEqual(res, {
      _argv: [],
      title: [TITLE, TITLE2],
      wait: WAIT,
    })
  },
  'parses boolean'({ config }) {
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', '--list']
    const res = argufy(config, args)
    deepEqual(res, {
      _argv: [],
      list: true,
    })
  },
  'parses short boolean'({ config }) {
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', '-l']
    const res = argufy(config, args)
    deepEqual(res, {
      _argv: [],
      list: true,
    })
  },
  'parses a zero integer'() {
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', '--wait', '0']
    const res = argufy({
      wait: { short: 'w', number: true },
    }, args)
    deepEqual(res, {
      _argv: [],
      wait: 0,
    })
  },
  'extracts arguments which start with - only'() {
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', 'hello-world']
    const res = argufy({
      wait: { short: 'w', boolean: true },
    }, args)
    deepEqual(res, { _argv: [] })
  },
  'extracts all left arguments'() {
    const a = ['--arg', 'value']
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', 'hello-world', '-w', '100', ...a]
    const res = argufy({
      title: { command: true, multiple: true },
      wait: { short: 'w', number: true },
    }, args)
    deepEqual(res._argv, a)
  },
  'adds edge case with no argument to _argv'() {
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', '--wait']
    const res = argufy({
      wait: { short: 'w', number: true },
    }, args)
    deepEqual(res, { _argv: ['--wait'] })
  },
  'adds extra arguments to the list as _argv'() {
    const args = ['.nvm/versions/node/v8.10.0/bin/node', 'script', '--wait', '--title']
    const res = argufy({
      wait: { short: 'w', number: true },
    }, args)
    deepEqual(res, { _argv: ['--wait', '--title'] })
  },
}

export default T
